# 🚀 programmering.no | 🤓 matematikk.as
# - Eksempel på NoneType

# Variabler
bruker_aktiv = None

# Ser om en bruker er registrert og aktiv
if bruker_aktiv == None:
    print("Bruker eksisterer ikke")
if bruker_aktiv == True:
    print("Bruker er aktiv")
if bruker_aktiv == False:
    print("Bruker er ikke aktiv")
