# 🚀 programmering.no | 🤓 matematikk.as
# - Hvordan bruke indeks for å få tak i en bokstav (char)

# Variabler
pyt = "Python 🐍"

# Print
print(pyt[0])
print(pyt[1])
print(pyt[2])
print(pyt[3])
print(pyt[4])
print(pyt[5])
print(pyt[6])
print(pyt[7])
