# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut summen av elementene i en liste med sum()

# Input
liste = [10, 20, 30]

# Sum
sum = sum(liste)

# Print
print(f"Liste                : {liste}")
print(f"Summen av elementene : {sum}")
