# 🚀 programmering.no | 🤓 matematikk.as
# - Loop gjennom elementene i listen med indeks

# Variabler
liste = ["A", "B", "C"]

# For hver iterasjon printes neste element
for i in range(len(liste)):
    print(liste[i])
