# 🚀 programmering.no | 🤓 matematikk.as
# - Gyldige variabelnavn

# Variabler
små         = "små bokstaver"
STORE       = "STORE BOKSTAVER"
tall_42     = 42
_sym_underscore = "_data_"

# Print
print(små)
