# 🚀 programmering.no | 🤓 matematikk.as
# - Oversikt over datatypene i Python

# Variabler
eks_str          = str()
eks_int          = int()
eks_float        = float()
eks_complex      = complex()
eks_list         = list()
eks_tuple        = tuple()
eks_range        = range(0, 10) # Må defineres med to intervall-grenser
eks_dict         = dict()
eks_set          = set()
eks_fronzenset   = frozenset()
eks_bool         = bool()
eks_bytes        = bytes()
eks_bytearray    = bytearray()
eks_memoryview   = memoryview(eks_bytearray) # Må defineres med et byte-objekt
eks_none         = None

# Print datatype
print("Datatypene i Python::")
print(type(eks_str))
print(type(eks_int))
print(type(eks_float))
print(type(eks_complex))
print(type(eks_list))
print(type(eks_tuple))
print(type(eks_range))
print(type(eks_dict))
print(type(eks_set))
print(type(eks_fronzenset))
print(type(eks_bool))
print(type(eks_bytes))
print(type(eks_bytearray))
print(type(eks_memoryview))
print(type(eks_none))
