# 🚀 programmering.no | 🤓 matematikk.as
# - Loop gjennom elementene i listen med element-variabel

# Variabler
liste = ["A", "B", "C"]

# For hver iterasjon printes neste element
for el in liste:
    print(el)
